@@ -1,22 +1,23 @@
 /*
- * Copyright(c) 2000 Apple Computer, Inc. All rights reserved.
+ * Copyright(c) 2000-2003 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
- *
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1(the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
- *
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
- *
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
+ * 
  * @APPLE_LICENSE_HEADER_END@
  */
 
@@ -39,9 +40,11 @@ SCPreferencesAddValue(SCPreferencesRef session, CFStringRef key, CFPropertyListR
 {
 	SCPreferencesPrivateRef	sessionPrivate	= (SCPreferencesPrivateRef)session;
 
-	SCLog(_sc_verbose, LOG_DEBUG, CFSTR("SCPreferencesAddValue:"));
-	SCLog(_sc_verbose, LOG_DEBUG, CFSTR("  key   = %@"), key);
-	SCLog(_sc_verbose, LOG_DEBUG, CFSTR("  value = %@"), value);
+	if (_sc_verbose) {
+		SCLog(TRUE, LOG_DEBUG, CFSTR("SCPreferencesAddValue:"));
+		SCLog(TRUE, LOG_DEBUG, CFSTR("  key   = %@"), key);
+		SCLog(TRUE, LOG_DEBUG, CFSTR("  value = %@"), value);
+	}
 
 	sessionPrivate->accessed = TRUE;
 
