@@ -1,22 +1,23 @@
 /*
- * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 2000-2003 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
- *
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
- *
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
- *
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
+ * 
  * @APPLE_LICENSE_HEADER_END@
  */
 
@@ -45,10 +46,6 @@
  * data associated with a key
  */
 #define	kSCDData	CFSTR("data")
-/*
- * instance value associated with a key
- */
-#define	kSCDInstance	CFSTR("instance")
 /*
  * client session ids watching a key and, since we can possibly have
  * multiple regex keys which reference the key, a count of active
@@ -74,12 +71,6 @@
  * keys which have changed since last call to SCDNotifierGetChanges()
  */
 #define	kSCDChangedKeys	CFSTR("changedKeys")
-/*
- * for notification keys which consist of a regular expression we keep
- * both the pattern string and the compiled regular expression
- */
-#define	kSCDRegexKeys	CFSTR("regexKeys")
-#define	kSCDRegexData	CFSTR("regexData")
 /*
  * keys which are to be removed when the session is closed
  */
@@ -89,31 +80,18 @@
 extern int			storeLocked;
 extern CFMutableDictionaryRef	storeData;
 extern CFMutableDictionaryRef	sessionData;
+extern CFMutableDictionaryRef	patternData;
 extern CFMutableSetRef		changedKeys;
 extern CFMutableSetRef		deferredRemovals;
 extern CFMutableSetRef		removedSessionKeys;
 extern CFMutableSetRef		needsNotification;
 
 extern CFMutableDictionaryRef	storeData_s;
+extern CFMutableDictionaryRef	patternData_s;
 extern CFMutableSetRef		changedKeys_s;
 extern CFMutableSetRef		deferredRemovals_s;
 extern CFMutableSetRef		removedSessionKeys_s;
 
-/*
- * "context" argument for CFDictionaryArrayApplier _addRegexWatcherByKey(),
- * _addRegexWatcherBySession(), and _removeRegexWatcherByKey() functions.
- */
-typedef struct {
-	SCDynamicStorePrivateRef	store;
-	regex_t				*preg;
-} addContext, *addContextRef;
-
-
-typedef struct {
-	SCDynamicStorePrivateRef	store;
-	regex_t				*preg;
-} removeContext, *removeContextRef;
-
 
 __BEGIN_DECLS
 
@@ -121,7 +99,8 @@ int
 __SCDynamicStoreOpen			(SCDynamicStoreRef	*store,
 					 CFStringRef		name);
 int
-__SCDynamicStoreClose			(SCDynamicStoreRef	*store);
+__SCDynamicStoreClose			(SCDynamicStoreRef	*store,
+					 Boolean		internal);
 
 int
 __SCDynamicStoreLock			(SCDynamicStoreRef	store,
@@ -140,26 +119,41 @@ __SCDynamicStoreCopyKeyList		(SCDynamicStoreRef	store,
 int
 __SCDynamicStoreAddValue		(SCDynamicStoreRef	store,
 					 CFStringRef		key,
-					 CFPropertyListRef	value);
+					 CFDataRef		value);
 
 int
 __SCDynamicStoreAddTemporaryValue	(SCDynamicStoreRef	store,
 					 CFStringRef		key,
-					 CFPropertyListRef	value);
+					 CFDataRef		value);
 
 int
 __SCDynamicStoreCopyValue		(SCDynamicStoreRef	store,
 					 CFStringRef		key,
-					 CFPropertyListRef	*value);
+					 CFDataRef		*value,
+					 Boolean		internal);
+
+int
+__SCDynamicStoreCopyMultiple		(SCDynamicStoreRef	store,
+					 CFArrayRef		keys,
+					 CFArrayRef		patterns,
+					 CFDictionaryRef	*values);
 
 int
 __SCDynamicStoreSetValue		(SCDynamicStoreRef	store,
 					 CFStringRef		key,
-					 CFPropertyListRef	value);
+					 CFDataRef		value,
+					 Boolean		internal);
+
+int
+__SCDynamicStoreSetMultiple		(SCDynamicStoreRef	store,
+					 CFDictionaryRef	keysToSet,
+					 CFArrayRef		keysToRemove,
+					 CFArrayRef		keysToNotify);
 
 int
 __SCDynamicStoreRemoveValue		(SCDynamicStoreRef	store,
-					 CFStringRef		key);
+					 CFStringRef		key,
+					 Boolean		internal);
 
 int
 __SCDynamicStoreTouchValue		(SCDynamicStoreRef	store,
@@ -167,7 +161,8 @@ __SCDynamicStoreTouchValue		(SCDynamicStoreRef	store,
 
 int
 __SCDynamicStoreNotifyValue		(SCDynamicStoreRef	store,
-					 CFStringRef		key);
+					 CFStringRef		key,
+					 Boolean		internal);
 
 int
 __SCDynamicStoreSnapshot		(SCDynamicStoreRef	store);
@@ -175,12 +170,19 @@ __SCDynamicStoreSnapshot		(SCDynamicStoreRef	store);
 int
 __SCDynamicStoreAddWatchedKey		(SCDynamicStoreRef	store,
 					 CFStringRef		key,
-					 Boolean		isRegex);
+					 Boolean		isRegex,
+					 Boolean		internal);
 
 int
 __SCDynamicStoreRemoveWatchedKey	(SCDynamicStoreRef	store,
 					 CFStringRef		key,
-					 Boolean		isRegex);
+					 Boolean		isRegex,
+					 Boolean		internal);
+
+int
+__SCDynamicStoreSetNotificationKeys	(SCDynamicStoreRef	store,
+					 CFArrayRef		keys,
+					 CFArrayRef		patterns);
 
 int
 __SCDynamicStoreCopyNotifiedKeys	(SCDynamicStoreRef	store,
@@ -211,30 +213,10 @@ void
 _addWatcher				(CFNumberRef		sessionNum,
 					 CFStringRef		watchedKey);
 
-void
-_addRegexWatcherByKey			(const void		*key,
-					 void			*val,
-					 void			*context);
-
-void
-_addRegexWatchersBySession		(const void		*key,
-					 void			*val,
-					 void			*context);
-
 void
 _removeWatcher				(CFNumberRef		sessionNum,
 					 CFStringRef		watchedKey);
 
-void
-_removeRegexWatcherByKey		(const void		*key,
-					 void			*val,
-					 void			*context);
-
-void
-_removeRegexWatchersBySession		(const void		*key,
-					 void			*val,
-					 void			*context);
-
 __END_DECLS
 
 #endif /* !_S_SCD_H */
