@@ -1,22 +1,23 @@
 /*
- * Copyright (c) 2000 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 2000-2003 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
- *
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
- *
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
- *
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
+ * 
  * @APPLE_LICENSE_HEADER_END@
  */
 
@@ -31,12 +32,17 @@
  */
 
 #include "scutil.h"
+#include "session.h"
 #include "notify.h"
 
 void
 do_open(int argc, char **argv)
 {
-	if (store)	CFRelease(store);
+	if (store) {
+		CFRelease(store);
+		CFRelease(watchedKeys);
+		CFRelease(watchedPatterns);
+	}
 
 	store = SCDynamicStoreCreate(NULL, CFSTR("scutil"), storeCallback, NULL);
 	if (!store) {
@@ -44,6 +50,9 @@ do_open(int argc, char **argv)
 		return;
 	}
 
+	watchedKeys     = CFArrayCreateMutable(NULL, 0, &kCFTypeArrayCallBacks);
+	watchedPatterns = CFArrayCreateMutable(NULL, 0, &kCFTypeArrayCallBacks);
+
 	return;
 }
 
@@ -57,9 +66,18 @@ do_close(int argc, char **argv)
 		notifyRls = NULL;
 	}
 
+	if (notifyRl) {
+		CFRunLoopStop(notifyRl);
+		notifyRl  = NULL;
+	}
+
 	if (store) {
 		CFRelease(store);
 		store = NULL;
+		CFRelease(watchedKeys);
+		watchedKeys = NULL;
+		CFRelease(watchedPatterns);
+		watchedPatterns = NULL;
 	}
 	return;
 }
